@@ -42,13 +42,15 @@ pref("browser.chromeURL", "chrome://browser/content/");
 
 pref("browser.startup.homepage", "about:firstrun");
 
-#if MOZ_PLATFORM_HILDON
-pref("browser.ui.cursor", false);
-#elifdef WINCE
-pref("browser.ui.cursor", false);
-#else // DESKTOP
-pref("browser.ui.cursor", true);
-#endif
+pref("browser.tabs.warnOnClose", true);
+
+pref("toolkit.screen.lock", false);
+
+// From libpref/src/init/all.js, extended to allow a slightly wider zoom range.
+pref("zoom.minPercent", 20);
+pref("zoom.maxPercent", 400);
+pref("toolkit.zoomManager.zoomValues", ".2,.3,.5,.67,.8,.9,1,1.1,1.2,1.33,1.5,1.7,2,2.4,3,4");
+pref("zoom.dpiScale", 150);
 
 /* use custom widget for html:select */
 pref("ui.use_native_popup_windows", true);
@@ -69,7 +71,7 @@ pref("browser.cache.memory.capacity", 1024); // kilobytes
 */
 #ifdef WINCE
 pref("tile.cache.size", 15); // tiles
-#elifdef MOZ_PLATFORM_HILDON
+#elifdef MOZ_PLATFORM_MAEMO
 pref("tile.cache.size", -1); // tiles
 #else
 pref("tile.cache.size", 30); // tiles
@@ -95,7 +97,7 @@ pref("network.http.max-connections", 6);
 pref("network.http.max-connections-per-server", 4);
 pref("network.http.max-persistent-connections-per-server", 4);
 pref("network.http.max-persistent-connections-per-proxy", 4);
-#ifdef MOZ_PLATFORM_HILDON
+#ifdef MOZ_ENABLE_LIBCONIC
 pref("network.autodial-helper.enabled", true);
 #endif
 
@@ -132,6 +134,11 @@ pref("signon.rememberSignons", true);
 pref("signon.expireMasterPassword", false);
 pref("signon.SignonFileName", "signons.txt");
 
+/* form helper */
+pref("formhelper.enabled", true);
+pref("formhelper.autozoom", true);
+pref("formhelper.restore", false);
+
 /* autocomplete */
 pref("browser.formfill.enable", true);
 
@@ -149,6 +156,9 @@ pref("xpinstall.dialog.progress.chrome", "chrome://browser/content/browser.xul")
 pref("xpinstall.dialog.progress.type.skin", "navigator:browser");
 pref("xpinstall.dialog.progress.type.chrome", "navigator:browser");
 pref("xpinstall.whitelist.add", "addons.mozilla.org");
+
+pref("extensions.autoupdate.enabled", true);
+pref("extensions.autoupdate.interval", 86400);
 pref("extensions.update.enabled", false);
 pref("extensions.update.interval", 86400);
 pref("extensions.dss.enabled", false);
@@ -157,6 +167,7 @@ pref("extensions.ignoreMTimeChanges", false);
 pref("extensions.logging.enabled", false);
 pref("extensions.hideInstallButton", true);
 pref("extensions.showMismatchUI", false);
+pref("extensions.hideUpdateButton", false);
 
 pref("extensions.update.url", "https://versioncheck.addons.mozilla.org/update/VersionCheck.php?reqVersion=%REQ_VERSION%&id=%ITEM_ID%&version=%ITEM_VERSION%&maxAppVersion=%ITEM_MAXAPPVERSION%&status=%ITEM_STATUS%&appID=%APP_ID%&appVersion=%APP_VERSION%&appOS=%APP_OS%&appABI=%APP_ABI%&locale=%APP_LOCALE%&currentAppVersion=%CURRENT_APP_VERSION%&updateType=%UPDATE_TYPE%");
 
@@ -182,8 +193,6 @@ pref("privacy.popups.showBrowserMessage", true);
 pref("keyword.enabled", true);
 pref("keyword.URL", "http://www.google.com/search?ie=UTF-8&oe=UTF-8&sourceid=navclient&gfns=1&q=");
 
-pref("snav.enabled", false);
-
 pref("accessibility.typeaheadfind", false);
 pref("accessibility.typeaheadfind.timeout", 5000);
 pref("accessibility.typeaheadfind.flashBar", 1);
@@ -243,7 +252,7 @@ pref("browser.urlbar.autoFill", false);
 pref("browser.urlbar.matchOnlyTyped", false);
 pref("browser.urlbar.matchBehavior", 1);
 pref("browser.urlbar.filter.javascript", true);
-pref("browser.urlbar.maxRichResults", 12);
+pref("browser.urlbar.maxRichResults", 24); // increased so we see more results when portrait
 pref("browser.urlbar.search.chunkSize", 1000);
 pref("browser.urlbar.search.timeout", 100);
 pref("browser.urlbar.restrict.history", "^");
@@ -313,7 +322,7 @@ pref("privacy.item.sessions", true);
 pref("privacy.item.geolocation", true);
 pref("privacy.item.siteSettings", true);
 
-#ifdef MOZ_PLATFORM_HILDON
+#ifdef MOZ_PLATFORM_MAEMO
 pref("plugins.force.wmode", "opaque");
 #endif
 
@@ -355,11 +364,23 @@ pref("browser.ui.kinetic.decelerationRate", 20);
 pref("browser.ui.kinetic.speedSensitivity", 80);
 pref("browser.ui.kinetic.swipeLength", 160);
 
+// zooming
+pref("browser.ui.zoom.pageFitGranularity", 10); // don't zoom to fit by less than 1/10.
+
+// Touch radius (area around the touch location to look for target elements):
+pref("browser.ui.touch.left", 8);
+pref("browser.ui.touch.right", 8);
+pref("browser.ui.touch.top", 12);
+pref("browser.ui.touch.bottom", 4);
+pref("browser.ui.touch.weight.visited", 120); // percentage
+
 // plugins
 pref("plugin.disable", true);
 pref("plugin.default_plugin_disabled", true);
 
 // product URLs
+// The breakpad report server to link to in about:crashes
+pref("breakpad.reportURL", "http://crash-stats.mozilla.com/report/index/");
 pref("app.releaseNotesURL", "http://www.mozilla.com/%LOCALE%/mobile/%VERSION%/releasenotes/");
 //pref("app.support.baseURL", "http://support.mozilla.com/1/mobile/%VERSION%/%OS%/%LOCALE%/");
 pref("app.support.baseURL", "http://mobile.support.mozilla.com/");
@@ -407,13 +428,14 @@ pref("browser.search.param.yahoo-fr-ja", "mozff");
 #endif
 
 /* app update prefs */
+pref("app.update.timer", 60000); // milliseconds (1 min)
+
 #ifdef MOZ_UPDATER
 pref("app.update.auto", true);
 pref("app.update.channel", "@MOZ_UPDATE_CHANNEL@");
-pref("app.update.timer", 600000);
 pref("app.update.mode", 1);
 pref("app.update.silent", false);
-pref("app.update.url", "https://aus2.mozilla.org/update/3/%APP_ID%/%VERSION%/%GRE_MILESTONE%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/update.xml");
+pref("app.update.url", "https://aus2.mozilla.org/update/4/%PRODUCT%/%VERSION%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/%PLATFORM_VERSION%/update.xml");
 pref("app.update.nagTimer.restart", 86400);
 pref("app.update.promptWaitTime", 43200);
 pref("app.update.idletime", 60);
@@ -429,3 +451,20 @@ pref("app.update.url.details", "http://www.mozilla.com/%LOCALE%/mobile/releases/
 pref("app.update.interval", 28800);
 #endif
 #endif
+
+// replace newlines with spaces on paste into single-line text boxes
+pref("editor.singleLine.pasteNewlines", 2);
+
+#ifdef MOZ_PLATFORM_MAEMO
+// update fonts for better readability
+pref("font.default.x-baltic", "SwissA");
+pref("font.default.x-central-euro", "SwissA");
+pref("font.default.x-cyrillic", "SwissA");
+pref("font.default.x-unicode", "SwissA");
+pref("font.default.x-user-def", "SwissA");
+pref("font.default.x-western", "SwissA");
+#endif
+
+// See bug 545869 for details on why these are set the way they are
+pref("network.buffer.cache.count", 24);
+pref("network.buffer.cache.size",  16384);
