@@ -23,6 +23,7 @@
  * Contributor(s):
  *   Roy Frostig <rfrostig@mozilla.com>
  *   Stuart Parmenter <stuart@mozilla.com>
+ *   Matt Brubeck <mbrubeck@mozilla.com>
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -40,8 +41,6 @@
 
 let Ci = Components.interfaces;
 
-const kBrowserViewZoomLevelMin = 0.2;
-const kBrowserViewZoomLevelMax = 4.0;
 const kBrowserFormZoomLevelMin = 1.0;
 const kBrowserFormZoomLevelMax = 2.0;
 const kBrowserViewZoomLevelPrecision = 10000;
@@ -154,16 +153,6 @@ BrowserView.Util = {
     return visibleRect.intersect(browserViewportState.viewportRect);
   },
 
-  clampZoomLevel: function clampZoomLevel(zl) {
-    let bounded = Math.min(Math.max(kBrowserViewZoomLevelMin, zl), kBrowserViewZoomLevelMax);
-    let rounded = Math.round(bounded * kBrowserViewZoomLevelPrecision) / kBrowserViewZoomLevelPrecision;
-    return (rounded) ? rounded : 1.0;
-  },
-
-  pageZoomLevel: function pageZoomLevel(visibleRect, browserW, browserH) {
-    return BrowserView.Util.clampZoomLevel(visibleRect.width / browserW);
-  },
-
   createBrowserViewportState: function createBrowserViewportState() {
     return new BrowserView.BrowserViewportState(new Rect(0, 0, 1, 1), 0, 0, 1);
   },
@@ -215,14 +204,24 @@ BrowserView.Util = {
   },
 
   initContainer: function initContainer(container, visibleRect) {
-    container.style.width    = visibleRect.width  + 'px';
-    container.style.height   = visibleRect.height + 'px';
+    container.style.width = visibleRect.width  + 'px';
+    container.style.height = visibleRect.height + 'px';
     container.style.overflow = '-moz-hidden-unscrollable';
   },
 
   resizeContainerToViewport: function resizeContainerToViewport(container, viewportRect) {
-    container.style.width  = viewportRect.width  + 'px';
+    container.style.width = viewportRect.width  + 'px';
     container.style.height = viewportRect.height + 'px';
+  },
+
+  ensureMozScrolledAreaEvent: function ensureMozScrolledAreaEvent(aBrowser, aWidth, aHeight) {
+    let event = document.createEvent("Event");
+    event.initEvent("MozScrolledAreaChanged", true, false);
+    event.x = 0;
+    event.y = 0;
+    event.width = aWidth;
+    event.height = aHeight;
+    aBrowser.dispatchEvent(event);
   }
 };
 
@@ -250,7 +249,7 @@ BrowserView.prototype = {
       let sysInfo = Cc["@mozilla.org/system-info;1"].getService(Ci.nsIPropertyBag2);
       let device = sysInfo.get("device");
       switch (device) {
-#ifdef MOZ_PLATFORM_HILDON
+#ifdef MOZ_PLATFORM_MAEMO
         case "Nokia N900":
           cacheSize = 26;
           break;
@@ -310,7 +309,7 @@ BrowserView.prototype = {
     if (!bvs)
       return;
 
-    let newZoomLevel = BrowserView.Util.clampZoomLevel(zoomLevel);
+    let newZoomLevel = this.clampZoomLevel(zoomLevel);
     if (newZoomLevel != bvs.zoomLevel) {
       let browserW = this.viewportToBrowser(bvs.viewportRect.right);
       let browserH = this.viewportToBrowser(bvs.viewportRect.bottom);
@@ -335,6 +334,22 @@ BrowserView.prototype = {
     return bvs.zoomLevel;
   },
 
+  clampZoomLevel: function clampZoomLevel(zl) {
+    let bounded = Math.min(Math.max(ZoomManager.MIN, zl), ZoomManager.MAX);
+
+    let bvs = this._browserViewportState;
+    if (bvs) {
+      let md = bvs.metaData;
+      if (md && md.minZoom)
+        bounded = Math.max(bounded, md.minZoom);
+      if (md && md.maxZoom)
+        bounded = Math.min(bounded, md.maxZoom);
+    }
+
+    let rounded = Math.round(bounded * kBrowserViewZoomLevelPrecision) / kBrowserViewZoomLevelPrecision;
+    return rounded || 1.0;
+  },
+
   beginOffscreenOperation: function beginOffscreenOperation(rect) {
     if (this._offscreenDepth == 0) {
       let vis = this.getVisibleRect();
@@ -517,7 +532,7 @@ BrowserView.prototype = {
         rects.push(r);
     }
 
-    tm.dirtyRects(rects, this.isRendering());
+    tm.dirtyRects(rects, this.isRendering(), true);
   },
 
   /** If browser scrolls, pan content to new scroll area. */
@@ -574,14 +589,14 @@ BrowserView.prototype = {
     }
   },
 
-  /** Call when default zoomToPage value may change. */
+  /** Call when default zoom level may change. */
   updateDefaultZoom: function updateDefaultZoom() {
     let bvs = this._browserViewportState;
     if (!bvs)
       return false;
 
     let isDefault = (bvs.zoomLevel == bvs.defaultZoomLevel);
-    bvs.defaultZoomLevel = this.getZoomForPage();
+    bvs.defaultZoomLevel = this.getDefaultZoomLevel();
     if (isDefault)
       this.setZoomLevel(bvs.defaultZoomLevel);
     return isDefault;
@@ -594,29 +609,30 @@ BrowserView.prototype = {
     return bvs.zoomLevel == bvs.defaultZoomLevel;
   },
 
-  zoomToPage: function zoomToPage() {
+  getDefaultZoomLevel: function getDefaultZoomLevel() {
     let bvs = this._browserViewportState;
-    if (bvs) {
-      this.setZoomLevel(this.getZoomForPage());
-      bvs.defaultZoomLevel = bvs.zoomLevel;  // make sure default zl is up to date
-    }
-  },
-
-  getZoomForPage: function getZoomForPage() {
-    let browser = this._browser;
-    if (!browser)
+    if (!bvs)
       return 0;
 
-    let metaData = Util.contentIsHandheld(browser);
-    if (metaData.reason == "handheld" || metaData.reason == "doctype")
-      return 1;
-    else if (metaData.reason == "viewport" && metaData.scale > 0)
-      return metaData.scale;
+    let pageZoom = this.getPageZoomLevel();
 
+    // If pageZoom is "almost" 100%, zoom in to exactly 100% (bug 454456).
+    let granularity = gPrefService.getIntPref("browser.ui.zoom.pageFitGranularity");
+    let threshold = 1 - 1 / granularity;
+    if (threshold < pageZoom && pageZoom < 1)
+      pageZoom = 1;
+
+    let md = bvs.metaData;
+    if (md && md.defaultZoom)
+      return Math.max(pageZoom, this.clampZoomLevel(md.defaultZoom));
+
+    return pageZoom;
+  },
+
+  getPageZoomLevel: function getPageZoomLevel() {
     let bvs = this._browserViewportState;  // browser exists, so bvs must as well
-    let w = this.viewportToBrowser(bvs.viewportRect.right);
-    let h = this.viewportToBrowser(bvs.viewportRect.bottom);
-    return BrowserView.Util.pageZoomLevel(this.getVisibleRect(), w, h);
+    let browserW = this.viewportToBrowser(bvs.viewportRect.right);
+    return this.clampZoomLevel(this.getVisibleRect().width / browserW);
   },
 
   zoom: function zoom(aDirection) {
@@ -634,6 +650,13 @@ BrowserView.prototype = {
     this.setZoomLevel(bvs.zoomLevel + zoomDelta);
   },
 
+  get allowZoom() {
+    let bvs = this._browserViewportState;
+    if (!bvs || !bvs.metaData)
+      return true;
+    return bvs.metaData.allowZoom;
+  },
+
   //
   // MozAfterPaint events do not guarantee to inform us of all
   // invalidated paints (See
@@ -641,7 +664,7 @@ BrowserView.prototype = {
   // for details on what the event *does* guarantee).  This is only an
   // issue when the same current <browser> is used to navigate to a
   // new page.  Unless a zoom was issued during the page transition
-  // (e.g. a call to zoomToPage() or something of that nature), we
+  // (e.g. a call to setZoomLevel() or something of that nature), we
   // aren't guaranteed that we've actually invalidated the entire
   // page.  We don't want to leave bits of the previous page in the
   // view of the new one, so this method exists as a way for Browser
@@ -655,13 +678,13 @@ BrowserView.prototype = {
   // of the following two conditions is satisfied.  Either
   //
   //   (1) Pages have different widths so the Browser calls a
-  //       zoomToPage() which forces a dirtyAll, or
+  //       updateDefaultZoom() which forces a dirtyAll, or
   //   (2) MozAfterPaint does indeed inform us of dirtyRects covering
   //       the entire page (everything that could possibly become
   //       visible).
   /**
    * Invalidates the entire page by throwing away any cached graphical
-   * portions of the view and refusing to allow a zoomToPage() until
+   * portions of the view and refusing to allow a updateDefaultZoom() until
    * the next explicit update of the viewport dimensions.
    *
    * This method should be called when the <browser> last set by
